PCB Environment: fancy_lock_guard Struct Reference

PCB Environment 2

Loading...
Searching...
No Matches
Public Member Functions | Data Fields
fancy_lock_guard Struct Reference

## Public Member Functions
| fancy_lock_guard (std::mutex &mutex)
| operator bool () const

## Data Fields
std::lock_guard< std::mutex > | _lock

The documentation for this struct was generated from the following file:

- /home/chr/devel/PhD/Environment/pub/PCBEnv/pcbenv/cxx/Util/FancyLock.hpp